Documentation
¶
Index ¶
- Variables
- type Enum
- type Message
- func (*Message) Descriptor() ([]byte, []int)deprecated
- func (x *Message) GetAND() string
- func (x *Message) GetBool() bool
- func (x *Message) GetBoolOptional() bool
- func (x *Message) GetBytes() []byte
- func (x *Message) GetBytesOptional() []byte
- func (x *Message) GetDouble() float64
- func (x *Message) GetDoubleOptional() float64
- func (x *Message) GetDuration() *durationpb.Duration
- func (x *Message) GetDurationOptional() *durationpb.Duration
- func (x *Message) GetEnum() Enum
- func (x *Message) GetEnumOptional() Enum
- func (x *Message) GetF32() uint32
- func (x *Message) GetF32Optional() uint32
- func (x *Message) GetF64() uint64
- func (x *Message) GetF64Optional() uint64
- func (x *Message) GetFloat() float32
- func (x *Message) GetFloatOptional() float32
- func (x *Message) GetI32() int32
- func (x *Message) GetI32Complexity() int32
- func (x *Message) GetI32Optional() int32
- func (x *Message) GetI64() int64
- func (x *Message) GetI64Optional() int64
- func (x *Message) GetIN() string
- func (x *Message) GetInputOnlyStr() string
- func (x *Message) GetMapI32Str() map[int32]string
- func (x *Message) GetMapStrBool() map[string]bool
- func (x *Message) GetMapStrBytes() map[string][]byte
- func (x *Message) GetMapStrDouble() map[string]float64
- func (x *Message) GetMapStrDuration() map[string]*durationpb.Duration
- func (x *Message) GetMapStrEnum() map[string]Enum
- func (x *Message) GetMapStrF32() map[string]uint32
- func (x *Message) GetMapStrF64() map[string]uint64
- func (x *Message) GetMapStrFloat() map[string]float32
- func (x *Message) GetMapStrI32() map[string]int32
- func (x *Message) GetMapStrI64() map[string]int64
- func (x *Message) GetMapStrMsg() map[string]*Message
- func (x *Message) GetMapStrS32() map[string]int32
- func (x *Message) GetMapStrS64() map[string]int64
- func (x *Message) GetMapStrSf32() map[string]int32
- func (x *Message) GetMapStrSf64() map[string]int64
- func (x *Message) GetMapStrStr() map[string]string
- func (x *Message) GetMapStrTimestamp() map[string]*timestamppb.Timestamp
- func (x *Message) GetMapStrU32() map[string]uint32
- func (x *Message) GetMapStrU64() map[string]uint64
- func (x *Message) GetMsgOptional() *Message
- func (x *Message) GetNOT() *Message
- func (x *Message) GetName() string
- func (x *Message) GetNoFilter() string
- func (x *Message) GetNoFilterMsg() *Message
- func (x *Message) GetNoSearch() string
- func (x *Message) GetNonEmptyBool() bool
- func (x *Message) GetNonEmptyBytes() []byte
- func (x *Message) GetNonEmptyDouble() float64
- func (x *Message) GetNonEmptyDuration() *durationpb.Duration
- func (x *Message) GetNonEmptyEnum() Enum
- func (x *Message) GetNonEmptyF32() uint32
- func (x *Message) GetNonEmptyF64() uint64
- func (x *Message) GetNonEmptyFloat() float32
- func (x *Message) GetNonEmptyI32() int32
- func (x *Message) GetNonEmptyI64() int64
- func (x *Message) GetNonEmptyS32() int32
- func (x *Message) GetNonEmptyS64() int64
- func (x *Message) GetNonEmptySf32() int32
- func (x *Message) GetNonEmptySf64() int64
- func (x *Message) GetNonEmptyStr() string
- func (x *Message) GetNonEmptyStruct() *structpb.Struct
- func (x *Message) GetNonEmptyTimestamp() *timestamppb.Timestamp
- func (x *Message) GetNonEmptyU32() uint32
- func (x *Message) GetNonEmptyU64() uint64
- func (x *Message) GetOR() string
- func (m *Message) GetOneof() isMessage_Oneof
- func (x *Message) GetOneofBool() bool
- func (x *Message) GetOneofBytes() []byte
- func (x *Message) GetOneofDouble() float64
- func (x *Message) GetOneofDuration() *durationpb.Duration
- func (x *Message) GetOneofEnum() Enum
- func (x *Message) GetOneofF32() uint32
- func (x *Message) GetOneofF64() uint64
- func (x *Message) GetOneofFloat() float32
- func (x *Message) GetOneofI32() int32
- func (x *Message) GetOneofI64() int64
- func (x *Message) GetOneofMsg() *Message
- func (x *Message) GetOneofS32() int32
- func (x *Message) GetOneofS64() int64
- func (x *Message) GetOneofSf32() int32
- func (x *Message) GetOneofSf64() int64
- func (x *Message) GetOneofStr() string
- func (x *Message) GetOneofStruct() *structpb.Struct
- func (x *Message) GetOneofTimestamp() *timestamppb.Timestamp
- func (x *Message) GetOneofU32() uint32
- func (x *Message) GetOneofU64() uint64
- func (x *Message) GetPoint() *Point
- func (x *Message) GetPointNonTraversal() *Point
- func (x *Message) GetRpBool() []bool
- func (x *Message) GetRpBytes() [][]byte
- func (x *Message) GetRpDouble() []float64
- func (x *Message) GetRpDuration() []*durationpb.Duration
- func (x *Message) GetRpEnum() []Enum
- func (x *Message) GetRpF32() []uint32
- func (x *Message) GetRpF64() []uint64
- func (x *Message) GetRpFloat() []float32
- func (x *Message) GetRpI32() []int32
- func (x *Message) GetRpI64() []int64
- func (x *Message) GetRpS32() []int32
- func (x *Message) GetRpS64() []int64
- func (x *Message) GetRpSf32() []int32
- func (x *Message) GetRpSf64() []int64
- func (x *Message) GetRpStr() []string
- func (x *Message) GetRpStruct() []*structpb.Struct
- func (x *Message) GetRpSub() []*Message
- func (x *Message) GetRpTimestamp() []*timestamppb.Timestamp
- func (x *Message) GetRpU32() []uint32
- func (x *Message) GetRpU64() []uint64
- func (x *Message) GetS32() int32
- func (x *Message) GetS32Optional() int32
- func (x *Message) GetS64() int64
- func (x *Message) GetS64Optional() int64
- func (x *Message) GetSf32() int32
- func (x *Message) GetSf32Optional() int32
- func (x *Message) GetSf64() int64
- func (x *Message) GetSf64Optional() int64
- func (x *Message) GetStr() string
- func (x *Message) GetStrOptional() string
- func (x *Message) GetStruct() *structpb.Struct
- func (x *Message) GetStructOptional() *structpb.Struct
- func (x *Message) GetSub() *Message
- func (x *Message) GetTimestamp() *timestamppb.Timestamp
- func (x *Message) GetTimestampOptional() *timestamppb.Timestamp
- func (x *Message) GetU32() uint32
- func (x *Message) GetU32Optional() uint32
- func (x *Message) GetU64() uint64
- func (x *Message) GetU64Optional() uint64
- func (*Message) ProtoMessage()
- func (x *Message) ProtoReflect() protoreflect.Message
- func (x *Message) Reset()
- func (x *Message) String() string
- type Message_OneofBool
- type Message_OneofBytes
- type Message_OneofDouble
- type Message_OneofDuration
- type Message_OneofEnum
- type Message_OneofF32
- type Message_OneofF64
- type Message_OneofFloat
- type Message_OneofI32
- type Message_OneofI64
- type Message_OneofMsg
- type Message_OneofS32
- type Message_OneofS64
- type Message_OneofSf32
- type Message_OneofSf64
- type Message_OneofStr
- type Message_OneofStruct
- type Message_OneofTimestamp
- type Message_OneofU32
- type Message_OneofU64
- type Point
Constants ¶
This section is empty.
Variables ¶
var ( Enum_name = map[int32]string{ 0: "UNKNOWN", 1: "ONE", 2: "TWO", 3: "THREE", } Enum_value = map[string]int32{ "UNKNOWN": 0, "ONE": 1, "TWO": 2, "THREE": 3, } )
Enum value maps for Enum.
var File_internal_testpb_message_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Enum ¶
type Enum int32
func (Enum) Descriptor ¶
func (Enum) Descriptor() protoreflect.EnumDescriptor
func (Enum) EnumDescriptor
deprecated
func (Enum) Number ¶
func (x Enum) Number() protoreflect.EnumNumber
func (Enum) Type ¶
func (Enum) Type() protoreflect.EnumType
type Message ¶
type Message struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Str string `protobuf:"bytes,2,opt,name=str,proto3" json:"str,omitempty"`
I32 int32 `protobuf:"varint,3,opt,name=i32,proto3" json:"i32,omitempty"`
I64 int64 `protobuf:"varint,4,opt,name=i64,proto3" json:"i64,omitempty"`
U32 uint32 `protobuf:"varint,5,opt,name=u32,proto3" json:"u32,omitempty"`
U64 uint64 `protobuf:"varint,6,opt,name=u64,proto3" json:"u64,omitempty"`
S32 int32 `protobuf:"zigzag32,7,opt,name=s32,proto3" json:"s32,omitempty"`
S64 int64 `protobuf:"zigzag64,8,opt,name=s64,proto3" json:"s64,omitempty"`
F32 uint32 `protobuf:"fixed32,9,opt,name=f32,proto3" json:"f32,omitempty"`
F64 uint64 `protobuf:"fixed64,10,opt,name=f64,proto3" json:"f64,omitempty"`
Sf32 int32 `protobuf:"fixed32,11,opt,name=sf32,proto3" json:"sf32,omitempty"`
Sf64 int64 `protobuf:"fixed64,12,opt,name=sf64,proto3" json:"sf64,omitempty"`
Bool bool `protobuf:"varint,13,opt,name=bool,proto3" json:"bool,omitempty"`
Bytes []byte `protobuf:"bytes,14,opt,name=bytes,proto3" json:"bytes,omitempty"`
Float float32 `protobuf:"fixed32,15,opt,name=float,proto3" json:"float,omitempty"`
Double float64 `protobuf:"fixed64,16,opt,name=double,proto3" json:"double,omitempty"`
RpStr []string `protobuf:"bytes,17,rep,name=rp_str,json=rpStr,proto3" json:"rp_str,omitempty"`
RpI32 []int32 `protobuf:"varint,18,rep,packed,name=rp_i32,json=rpI32,proto3" json:"rp_i32,omitempty"`
RpI64 []int64 `protobuf:"varint,19,rep,packed,name=rp_i64,json=rpI64,proto3" json:"rp_i64,omitempty"`
RpU32 []uint32 `protobuf:"varint,20,rep,packed,name=rp_u32,json=rpU32,proto3" json:"rp_u32,omitempty"`
RpU64 []uint64 `protobuf:"varint,21,rep,packed,name=rp_u64,json=rpU64,proto3" json:"rp_u64,omitempty"`
RpS32 []int32 `protobuf:"zigzag32,22,rep,packed,name=rp_s32,json=rpS32,proto3" json:"rp_s32,omitempty"`
RpS64 []int64 `protobuf:"zigzag64,23,rep,packed,name=rp_s64,json=rpS64,proto3" json:"rp_s64,omitempty"`
RpF32 []uint32 `protobuf:"fixed32,24,rep,packed,name=rp_f32,json=rpF32,proto3" json:"rp_f32,omitempty"`
RpF64 []uint64 `protobuf:"fixed64,25,rep,packed,name=rp_f64,json=rpF64,proto3" json:"rp_f64,omitempty"`
RpSf32 []int32 `protobuf:"fixed32,26,rep,packed,name=rp_sf32,json=rpSf32,proto3" json:"rp_sf32,omitempty"`
RpSf64 []int64 `protobuf:"fixed64,27,rep,packed,name=rp_sf64,json=rpSf64,proto3" json:"rp_sf64,omitempty"`
RpBool []bool `protobuf:"varint,28,rep,packed,name=rp_bool,json=rpBool,proto3" json:"rp_bool,omitempty"`
RpBytes [][]byte `protobuf:"bytes,29,rep,name=rp_bytes,json=rpBytes,proto3" json:"rp_bytes,omitempty"`
RpFloat []float32 `protobuf:"fixed32,30,rep,packed,name=rp_float,json=rpFloat,proto3" json:"rp_float,omitempty"`
RpDouble []float64 `protobuf:"fixed64,31,rep,packed,name=rp_double,json=rpDouble,proto3" json:"rp_double,omitempty"`
Timestamp *timestamppb.Timestamp `protobuf:"bytes,32,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
Duration *durationpb.Duration `protobuf:"bytes,33,opt,name=duration,proto3" json:"duration,omitempty"`
Struct *structpb.Struct `protobuf:"bytes,34,opt,name=struct,proto3" json:"struct,omitempty"`
RpTimestamp []*timestamppb.Timestamp `protobuf:"bytes,35,rep,name=rp_timestamp,json=rpTimestamp,proto3" json:"rp_timestamp,omitempty"`
RpDuration []*durationpb.Duration `protobuf:"bytes,36,rep,name=rp_duration,json=rpDuration,proto3" json:"rp_duration,omitempty"`
RpStruct []*structpb.Struct `protobuf:"bytes,37,rep,name=rp_struct,json=rpStruct,proto3" json:"rp_struct,omitempty"`
Enum Enum `protobuf:"varint,38,opt,name=enum,proto3,enum=testpb.Enum" json:"enum,omitempty"`
RpEnum []Enum `protobuf:"varint,39,rep,packed,name=rp_enum,json=rpEnum,proto3,enum=testpb.Enum" json:"rp_enum,omitempty"`
Sub *Message `protobuf:"bytes,40,opt,name=sub,proto3" json:"sub,omitempty"`
RpSub []*Message `protobuf:"bytes,41,rep,name=rp_sub,json=rpSub,proto3" json:"rp_sub,omitempty"`
NoFilter string `protobuf:"bytes,42,opt,name=no_filter,json=noFilter,proto3" json:"no_filter,omitempty"`
NoFilterMsg *Message `protobuf:"bytes,43,opt,name=no_filter_msg,json=noFilterMsg,proto3" json:"no_filter_msg,omitempty"`
I32Complexity int32 `protobuf:"varint,44,opt,name=i32_complexity,json=i32Complexity,proto3" json:"i32_complexity,omitempty"`
MapStrStr map[string]string `` /* 179-byte string literal not displayed */
MapStrI32 map[string]int32 `` /* 180-byte string literal not displayed */
MapStrI64 map[string]int64 `` /* 180-byte string literal not displayed */
MapStrU32 map[string]uint32 `` /* 180-byte string literal not displayed */
MapStrU64 map[string]uint64 `` /* 180-byte string literal not displayed */
MapStrS32 map[string]int32 `` /* 182-byte string literal not displayed */
MapStrS64 map[string]int64 `` /* 182-byte string literal not displayed */
MapStrF32 map[string]uint32 `` /* 181-byte string literal not displayed */
MapStrF64 map[string]uint64 `` /* 181-byte string literal not displayed */
MapStrSf32 map[string]int32 `` /* 184-byte string literal not displayed */
MapStrSf64 map[string]int64 `` /* 184-byte string literal not displayed */
MapStrBool map[string]bool `` /* 183-byte string literal not displayed */
MapStrBytes map[string][]byte `` /* 185-byte string literal not displayed */
MapStrFloat map[string]float32 `` /* 187-byte string literal not displayed */
MapStrDouble map[string]float64 `` /* 190-byte string literal not displayed */
MapStrEnum map[string]Enum `` /* 200-byte string literal not displayed */
MapStrMsg map[string]*Message `` /* 179-byte string literal not displayed */
MapStrTimestamp map[string]*timestamppb.Timestamp `` /* 197-byte string literal not displayed */
MapStrDuration map[string]*durationpb.Duration `` /* 194-byte string literal not displayed */
I32Optional int32 `protobuf:"varint,64,opt,name=i32_optional,json=i32Optional,proto3" json:"i32_optional,omitempty"`
I64Optional int64 `protobuf:"varint,65,opt,name=i64_optional,json=i64Optional,proto3" json:"i64_optional,omitempty"`
U32Optional uint32 `protobuf:"varint,66,opt,name=u32_optional,json=u32Optional,proto3" json:"u32_optional,omitempty"`
U64Optional uint64 `protobuf:"varint,67,opt,name=u64_optional,json=u64Optional,proto3" json:"u64_optional,omitempty"`
S32Optional int32 `protobuf:"zigzag32,68,opt,name=s32_optional,json=s32Optional,proto3" json:"s32_optional,omitempty"`
S64Optional int64 `protobuf:"zigzag64,69,opt,name=s64_optional,json=s64Optional,proto3" json:"s64_optional,omitempty"`
F32Optional uint32 `protobuf:"fixed32,70,opt,name=f32_optional,json=f32Optional,proto3" json:"f32_optional,omitempty"`
F64Optional uint64 `protobuf:"fixed64,71,opt,name=f64_optional,json=f64Optional,proto3" json:"f64_optional,omitempty"`
Sf32Optional int32 `protobuf:"fixed32,72,opt,name=sf32_optional,json=sf32Optional,proto3" json:"sf32_optional,omitempty"`
Sf64Optional int64 `protobuf:"fixed64,73,opt,name=sf64_optional,json=sf64Optional,proto3" json:"sf64_optional,omitempty"`
BoolOptional bool `protobuf:"varint,74,opt,name=bool_optional,json=boolOptional,proto3" json:"bool_optional,omitempty"`
StrOptional string `protobuf:"bytes,75,opt,name=str_optional,json=strOptional,proto3" json:"str_optional,omitempty"`
BytesOptional []byte `protobuf:"bytes,76,opt,name=bytes_optional,json=bytesOptional,proto3" json:"bytes_optional,omitempty"`
FloatOptional float32 `protobuf:"fixed32,77,opt,name=float_optional,json=floatOptional,proto3" json:"float_optional,omitempty"`
DoubleOptional float64 `protobuf:"fixed64,78,opt,name=double_optional,json=doubleOptional,proto3" json:"double_optional,omitempty"`
TimestampOptional *timestamppb.Timestamp `protobuf:"bytes,79,opt,name=timestamp_optional,json=timestampOptional,proto3" json:"timestamp_optional,omitempty"`
DurationOptional *durationpb.Duration `protobuf:"bytes,80,opt,name=duration_optional,json=durationOptional,proto3" json:"duration_optional,omitempty"`
StructOptional *structpb.Struct `protobuf:"bytes,81,opt,name=struct_optional,json=structOptional,proto3" json:"struct_optional,omitempty"`
EnumOptional Enum `protobuf:"varint,82,opt,name=enum_optional,json=enumOptional,proto3,enum=testpb.Enum" json:"enum_optional,omitempty"`
MsgOptional *Message `protobuf:"bytes,83,opt,name=msg_optional,json=msgOptional,proto3" json:"msg_optional,omitempty"`
// Types that are assignable to Oneof:
//
// *Message_OneofStr
// *Message_OneofI32
// *Message_OneofI64
// *Message_OneofU32
// *Message_OneofU64
// *Message_OneofS32
// *Message_OneofS64
// *Message_OneofF32
// *Message_OneofF64
// *Message_OneofSf32
// *Message_OneofSf64
// *Message_OneofBool
// *Message_OneofBytes
// *Message_OneofFloat
// *Message_OneofDouble
// *Message_OneofTimestamp
// *Message_OneofDuration
// *Message_OneofStruct
// *Message_OneofEnum
// *Message_OneofMsg
Oneof isMessage_Oneof `protobuf_oneof:"oneof"`
InputOnlyStr string `protobuf:"bytes,104,opt,name=input_only_str,json=inputOnlyStr,proto3" json:"input_only_str,omitempty"`
// This field is a keyword in the query language.
AND string `protobuf:"bytes,105,opt,name=AND,proto3" json:"AND,omitempty"`
// IN is a keyword in the query language.
NOT *Message `protobuf:"bytes,106,opt,name=NOT,proto3" json:"NOT,omitempty"`
// This field is a keyword in the query language.
OR string `protobuf:"bytes,107,opt,name=OR,proto3" json:"OR,omitempty"`
// This field is a keyword in the query language.
IN string `protobuf:"bytes,108,opt,name=IN,proto3" json:"IN,omitempty"`
NonEmptyStr string `protobuf:"bytes,109,opt,name=non_empty_str,json=nonEmptyStr,proto3" json:"non_empty_str,omitempty"`
NonEmptyI32 int32 `protobuf:"varint,110,opt,name=non_empty_i32,json=nonEmptyI32,proto3" json:"non_empty_i32,omitempty"`
NonEmptyI64 int64 `protobuf:"varint,111,opt,name=non_empty_i64,json=nonEmptyI64,proto3" json:"non_empty_i64,omitempty"`
NonEmptyU32 uint32 `protobuf:"varint,112,opt,name=non_empty_u32,json=nonEmptyU32,proto3" json:"non_empty_u32,omitempty"`
NonEmptyU64 uint64 `protobuf:"varint,113,opt,name=non_empty_u64,json=nonEmptyU64,proto3" json:"non_empty_u64,omitempty"`
NonEmptyS32 int32 `protobuf:"zigzag32,114,opt,name=non_empty_s32,json=nonEmptyS32,proto3" json:"non_empty_s32,omitempty"`
NonEmptyS64 int64 `protobuf:"zigzag64,115,opt,name=non_empty_s64,json=nonEmptyS64,proto3" json:"non_empty_s64,omitempty"`
NonEmptyF32 uint32 `protobuf:"fixed32,116,opt,name=non_empty_f32,json=nonEmptyF32,proto3" json:"non_empty_f32,omitempty"`
NonEmptyF64 uint64 `protobuf:"fixed64,117,opt,name=non_empty_f64,json=nonEmptyF64,proto3" json:"non_empty_f64,omitempty"`
NonEmptySf32 int32 `protobuf:"fixed32,118,opt,name=non_empty_sf32,json=nonEmptySf32,proto3" json:"non_empty_sf32,omitempty"`
NonEmptySf64 int64 `protobuf:"fixed64,119,opt,name=non_empty_sf64,json=nonEmptySf64,proto3" json:"non_empty_sf64,omitempty"`
NonEmptyBool bool `protobuf:"varint,120,opt,name=non_empty_bool,json=nonEmptyBool,proto3" json:"non_empty_bool,omitempty"`
NonEmptyBytes []byte `protobuf:"bytes,121,opt,name=non_empty_bytes,json=nonEmptyBytes,proto3" json:"non_empty_bytes,omitempty"`
NonEmptyFloat float32 `protobuf:"fixed32,122,opt,name=non_empty_float,json=nonEmptyFloat,proto3" json:"non_empty_float,omitempty"`
NonEmptyDouble float64 `protobuf:"fixed64,123,opt,name=non_empty_double,json=nonEmptyDouble,proto3" json:"non_empty_double,omitempty"`
NonEmptyTimestamp *timestamppb.Timestamp `protobuf:"bytes,124,opt,name=non_empty_timestamp,json=nonEmptyTimestamp,proto3" json:"non_empty_timestamp,omitempty"`
NonEmptyDuration *durationpb.Duration `protobuf:"bytes,125,opt,name=non_empty_duration,json=nonEmptyDuration,proto3" json:"non_empty_duration,omitempty"`
NonEmptyStruct *structpb.Struct `protobuf:"bytes,126,opt,name=non_empty_struct,json=nonEmptyStruct,proto3" json:"non_empty_struct,omitempty"`
NonEmptyEnum Enum `protobuf:"varint,127,opt,name=non_empty_enum,json=nonEmptyEnum,proto3,enum=testpb.Enum" json:"non_empty_enum,omitempty"`
Point *Point `protobuf:"bytes,128,opt,name=point,proto3" json:"point,omitempty"`
MapI32Str map[int32]string `` /* 181-byte string literal not displayed */
PointNonTraversal *Point `protobuf:"bytes,130,opt,name=point_non_traversal,json=pointNonTraversal,proto3" json:"point_non_traversal,omitempty"`
NoSearch string `protobuf:"bytes,131,opt,name=no_search,json=noSearch,proto3" json:"no_search,omitempty"`
// contains filtered or unexported fields
}
func (*Message) Descriptor
deprecated
func (*Message) GetBoolOptional ¶
func (*Message) GetBytesOptional ¶
func (*Message) GetDoubleOptional ¶
func (*Message) GetDuration ¶
func (x *Message) GetDuration() *durationpb.Duration
func (*Message) GetDurationOptional ¶
func (x *Message) GetDurationOptional() *durationpb.Duration
func (*Message) GetEnumOptional ¶
func (*Message) GetF32Optional ¶
func (*Message) GetF64Optional ¶
func (*Message) GetFloatOptional ¶
func (*Message) GetI32Complexity ¶
func (*Message) GetI32Optional ¶
func (*Message) GetI64Optional ¶
func (*Message) GetInputOnlyStr ¶
func (*Message) GetMapI32Str ¶
func (*Message) GetMapStrBool ¶
func (*Message) GetMapStrBytes ¶
func (*Message) GetMapStrDouble ¶
func (*Message) GetMapStrDuration ¶
func (x *Message) GetMapStrDuration() map[string]*durationpb.Duration
func (*Message) GetMapStrEnum ¶
func (*Message) GetMapStrF32 ¶
func (*Message) GetMapStrF64 ¶
func (*Message) GetMapStrFloat ¶
func (*Message) GetMapStrI32 ¶
func (*Message) GetMapStrI64 ¶
func (*Message) GetMapStrMsg ¶
func (*Message) GetMapStrS32 ¶
func (*Message) GetMapStrS64 ¶
func (*Message) GetMapStrSf32 ¶
func (*Message) GetMapStrSf64 ¶
func (*Message) GetMapStrStr ¶
func (*Message) GetMapStrTimestamp ¶
func (x *Message) GetMapStrTimestamp() map[string]*timestamppb.Timestamp
func (*Message) GetMapStrU32 ¶
func (*Message) GetMapStrU64 ¶
func (*Message) GetMsgOptional ¶
func (*Message) GetNoFilter ¶
func (*Message) GetNoFilterMsg ¶
func (*Message) GetNoSearch ¶
func (*Message) GetNonEmptyBool ¶
func (*Message) GetNonEmptyBytes ¶
func (*Message) GetNonEmptyDouble ¶
func (*Message) GetNonEmptyDuration ¶
func (x *Message) GetNonEmptyDuration() *durationpb.Duration
func (*Message) GetNonEmptyEnum ¶
func (*Message) GetNonEmptyF32 ¶
func (*Message) GetNonEmptyF64 ¶
func (*Message) GetNonEmptyFloat ¶
func (*Message) GetNonEmptyI32 ¶
func (*Message) GetNonEmptyI64 ¶
func (*Message) GetNonEmptyS32 ¶
func (*Message) GetNonEmptyS64 ¶
func (*Message) GetNonEmptySf32 ¶
func (*Message) GetNonEmptySf64 ¶
func (*Message) GetNonEmptyStr ¶
func (*Message) GetNonEmptyStruct ¶
func (*Message) GetNonEmptyTimestamp ¶
func (x *Message) GetNonEmptyTimestamp() *timestamppb.Timestamp
func (*Message) GetNonEmptyU32 ¶
func (*Message) GetNonEmptyU64 ¶
func (*Message) GetOneofBool ¶
func (*Message) GetOneofBytes ¶
func (*Message) GetOneofDouble ¶
func (*Message) GetOneofDuration ¶
func (x *Message) GetOneofDuration() *durationpb.Duration
func (*Message) GetOneofEnum ¶
func (*Message) GetOneofF32 ¶
func (*Message) GetOneofF64 ¶
func (*Message) GetOneofFloat ¶
func (*Message) GetOneofI32 ¶
func (*Message) GetOneofI64 ¶
func (*Message) GetOneofMsg ¶
func (*Message) GetOneofS32 ¶
func (*Message) GetOneofS64 ¶
func (*Message) GetOneofSf32 ¶
func (*Message) GetOneofSf64 ¶
func (*Message) GetOneofStr ¶
func (*Message) GetOneofStruct ¶
func (*Message) GetOneofTimestamp ¶
func (x *Message) GetOneofTimestamp() *timestamppb.Timestamp
func (*Message) GetOneofU32 ¶
func (*Message) GetOneofU64 ¶
func (*Message) GetPointNonTraversal ¶
func (*Message) GetRpBytes ¶
func (*Message) GetRpDouble ¶
func (*Message) GetRpDuration ¶
func (x *Message) GetRpDuration() []*durationpb.Duration
func (*Message) GetRpFloat ¶
func (*Message) GetRpStruct ¶
func (*Message) GetRpTimestamp ¶
func (x *Message) GetRpTimestamp() []*timestamppb.Timestamp
func (*Message) GetS32Optional ¶
func (*Message) GetS64Optional ¶
func (*Message) GetSf32Optional ¶
func (*Message) GetSf64Optional ¶
func (*Message) GetStrOptional ¶
func (*Message) GetStructOptional ¶
func (*Message) GetTimestamp ¶
func (x *Message) GetTimestamp() *timestamppb.Timestamp
func (*Message) GetTimestampOptional ¶
func (x *Message) GetTimestampOptional() *timestamppb.Timestamp
func (*Message) GetU32Optional ¶
func (*Message) GetU64Optional ¶
func (*Message) ProtoMessage ¶
func (*Message) ProtoMessage()
func (*Message) ProtoReflect ¶
func (x *Message) ProtoReflect() protoreflect.Message
type Message_OneofBool ¶
type Message_OneofBool struct {
OneofBool bool `protobuf:"varint,95,opt,name=oneof_bool,json=oneofBool,proto3,oneof"`
}
type Message_OneofBytes ¶
type Message_OneofBytes struct {
OneofBytes []byte `protobuf:"bytes,96,opt,name=oneof_bytes,json=oneofBytes,proto3,oneof"`
}
type Message_OneofDouble ¶
type Message_OneofDouble struct {
OneofDouble float64 `protobuf:"fixed64,98,opt,name=oneof_double,json=oneofDouble,proto3,oneof"`
}
type Message_OneofDuration ¶
type Message_OneofDuration struct {
OneofDuration *durationpb.Duration `protobuf:"bytes,100,opt,name=oneof_duration,json=oneofDuration,proto3,oneof"`
}
type Message_OneofEnum ¶
type Message_OneofEnum struct {
OneofEnum Enum `protobuf:"varint,102,opt,name=oneof_enum,json=oneofEnum,proto3,enum=testpb.Enum,oneof"`
}
type Message_OneofF32 ¶
type Message_OneofF32 struct {
OneofF32 uint32 `protobuf:"fixed32,91,opt,name=oneof_f32,json=oneofF32,proto3,oneof"`
}
type Message_OneofF64 ¶
type Message_OneofF64 struct {
OneofF64 uint64 `protobuf:"fixed64,92,opt,name=oneof_f64,json=oneofF64,proto3,oneof"`
}
type Message_OneofFloat ¶
type Message_OneofFloat struct {
OneofFloat float32 `protobuf:"fixed32,97,opt,name=oneof_float,json=oneofFloat,proto3,oneof"`
}
type Message_OneofI32 ¶
type Message_OneofI32 struct {
OneofI32 int32 `protobuf:"varint,85,opt,name=oneof_i32,json=oneofI32,proto3,oneof"`
}
type Message_OneofI64 ¶
type Message_OneofI64 struct {
OneofI64 int64 `protobuf:"varint,86,opt,name=oneof_i64,json=oneofI64,proto3,oneof"`
}
type Message_OneofMsg ¶
type Message_OneofMsg struct {
OneofMsg *Message `protobuf:"bytes,103,opt,name=oneof_msg,json=oneofMsg,proto3,oneof"`
}
type Message_OneofS32 ¶
type Message_OneofS32 struct {
OneofS32 int32 `protobuf:"zigzag32,89,opt,name=oneof_s32,json=oneofS32,proto3,oneof"`
}
type Message_OneofS64 ¶
type Message_OneofS64 struct {
OneofS64 int64 `protobuf:"zigzag64,90,opt,name=oneof_s64,json=oneofS64,proto3,oneof"`
}
type Message_OneofSf32 ¶
type Message_OneofSf32 struct {
OneofSf32 int32 `protobuf:"fixed32,93,opt,name=oneof_sf32,json=oneofSf32,proto3,oneof"`
}
type Message_OneofSf64 ¶
type Message_OneofSf64 struct {
OneofSf64 int64 `protobuf:"fixed64,94,opt,name=oneof_sf64,json=oneofSf64,proto3,oneof"`
}
type Message_OneofStr ¶
type Message_OneofStr struct {
OneofStr string `protobuf:"bytes,84,opt,name=oneof_str,json=oneofStr,proto3,oneof"`
}
type Message_OneofStruct ¶
type Message_OneofTimestamp ¶
type Message_OneofTimestamp struct {
OneofTimestamp *timestamppb.Timestamp `protobuf:"bytes,99,opt,name=oneof_timestamp,json=oneofTimestamp,proto3,oneof"`
}
type Message_OneofU32 ¶
type Message_OneofU32 struct {
OneofU32 uint32 `protobuf:"varint,87,opt,name=oneof_u32,json=oneofU32,proto3,oneof"`
}
type Message_OneofU64 ¶
type Message_OneofU64 struct {
OneofU64 uint64 `protobuf:"varint,88,opt,name=oneof_u64,json=oneofU64,proto3,oneof"`
}
type Point ¶
type Point struct {
X float32 `protobuf:"fixed32,1,opt,name=x,proto3" json:"x,omitempty"`
Y float32 `protobuf:"fixed32,2,opt,name=y,proto3" json:"y,omitempty"`
// contains filtered or unexported fields
}
func (*Point) Descriptor
deprecated
func (*Point) ProtoMessage ¶
func (*Point) ProtoMessage()
func (*Point) ProtoReflect ¶
func (x *Point) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.